@@ -4,7 +4,7 @@ class Milestone:
     def __init__(self, task):
         self.tasks = [task]
 
-    def basicHTML(self):
+    def asHTML(self, uid):
         return '\n'.join(['%(task)s<br>'%task for task in self.tasks])
 
 class Milestones:
