@@ -96,28 +96,37 @@ class Week:
         l = self.taskSummary()
         return '\n'.join(['<td>%d</td><td>%s %s</td>'%e for e in l])
 
-    def basicHTML(self):
+    def asHTML(self, uid):
+        uid = '%s-%s'%(self.week, uid)
         l = []
         old = None
+        n = 0
         for i in range(5):
             task = self.days[i]
+            title = ''
             if task is None:
                 label = '&nbsp;'
-            else:
-                label = cgi.escape(task.label())
-#                if task.isCompleted():
-#                    label = '<strike>%s</strike>'%label
-            if label != old:
-                l.append(label)
-                old = label
-            elif label != '&nbsp;':
+            elif task.label() == old:
                 l.append('...')
+            else:
+                old = label = task.label()
+                if len(label) > 30:
+                    title = cgi.escape(label)
+                    label = label[:27] + ' ...'
+                    n += 1
+                label = cgi.escape(label)
+                if title:
+                    l.append('<div id="t%s%s" class="tip">%s</div>'%(uid,
+                        n, title))
+                    l.append('''<a class="tiptarget" href="#"
+                        onmouseout="popUp(event,'t%s%s')"
+                        onmouseover="popUp(event,'t%s%s')"
+                        onclick="return false">%s</a>'''%(uid, n, uid, n,
+                        label))
+                else:
+                    l.append(label)
         return '\n'.join(l)
 
-    def xbasicHTML(self):
-        l = self.taskSummary()
-        return '\n'.join(['%s: %s %s<br>'%e for e in l])
-
     def taskSummary(self):
         current = None
         l = []
